@@ -12,9 +12,12 @@ from sphinx import __version__
 # the searchindex.js system relies upon the object types
 # in the PythonDomain to create search entries
 from sphinx.domains import ObjType
+from sphinx.util import logging
 
 PythonDomain.object_types['parameter'] = ObjType('parameter', 'param')
 
+LOG = logging.getLogger(__name__)
+
 
 def _is_html(app):
     return app.builder.name in ('html', 'readthedocs')
@@ -200,12 +203,12 @@ def add_stylesheet(app):
 
 
 def copy_stylesheet(app, exception):
-    app.info(
+    LOG.info(
         bold('The name of the builder is: %s' % app.builder.name), nonl=True)
 
     if not _is_html(app) or exception:
         return
-    app.info(bold('Copying sphinx_paramlinks stylesheet... '), nonl=True)
+    LOG.info(bold('Copying sphinx_paramlinks stylesheet... '), nonl=True)
 
     source = os.path.abspath(os.path.dirname(__file__))
 
@@ -215,7 +218,7 @@ def copy_stylesheet(app, exception):
     # give it the path to a .css file and it does the right thing.
     dest = os.path.join(app.builder.outdir, '_static', 'sphinx_paramlinks.css')
     copyfile(os.path.join(source, "sphinx_paramlinks.css"), dest)
-    app.info('done')
+    LOG.info('done')
 
 
 def build_index(app, doctree):
